@@ -1,4 +1,5 @@
 import click
+import colorama
 import sys
 
 from chia.daemon.client import acquire_connection_to_daemon
@@ -14,6 +15,15 @@ from typing import Optional, Tuple
 # Click drops leading dashes, and converts remaining dashes to underscores. e.g. --set-passphrase -> 'set_passphrase'
 PASSPHRASE_CLI_OPTION_NAMES = ["keys_root_path", "set_passphrase", "passphrase_file", "current_passphrase_file"]
 
+SAVE_MASTER_PASSPHRASE_WARNING = (
+    colorama.Fore.YELLOW
+    + colorama.Style.BRIGHT
+    + "\n!!! SECURITY WARNING !!!\n"
+    + colorama.Style.RESET_ALL
+    + "Other processes may be able to access your saved passphrase, possibly exposing your private keys.\n"
+    + "You should not save your passphrase unless you fully trust your environment.\n"
+)
+
 
 def remove_passphrase_options_from_cmd(cmd) -> None:
     """
@@ -43,15 +53,27 @@ def verify_passphrase_meets_requirements(
         raise Exception("Unexpected passphrase verification case")
 
 
+def prompt_for_passphrase(prompt: str) -> str:
+    if sys.platform == "win32" or sys.platform == "cygwin":
+        print(prompt, end="")
+        prompt = ""
+    return getpass(prompt)
+
+
 def prompt_to_save_passphrase() -> bool:
     save: bool = False
 
     try:
         if supports_os_passphrase_storage():
             location: Optional[str] = None
+            warning: Optional[str] = None
 
             if sys.platform == "darwin":
                 location = "macOS Keychain"
+                warning = SAVE_MASTER_PASSPHRASE_WARNING
+            elif sys.platform == "win32" or sys.platform == "cygwin":
+                location = "Windows Credential Manager"
+                warning = SAVE_MASTER_PASSPHRASE_WARNING
 
             if location is None:
                 raise ValueError("OS-specific credential store not specified")
@@ -61,6 +83,10 @@ def prompt_to_save_passphrase() -> bool:
                 "Your passphrase can be stored in your system's secure credential store. "
                 "Other Chia processes will be able to access your keys without prompting for your passphrase."
             )
+            if warning is not None:
+                colorama.init()
+
+                print(warning)
             save = prompt_yes_no(f"Would you like to save your passphrase to the {location} (y/n) ")
 
     except Exception as e:
@@ -120,7 +146,7 @@ def initialize_passphrase() -> None:
     Keychain.set_master_passphrase(current_passphrase=None, new_passphrase=passphrase, save_passphrase=save_passphrase)
 
 
-def set_or_update_passphrase(passphrase: Optional[str], current_passphrase: Optional[str]) -> bool:
+def set_or_update_passphrase(passphrase: Optional[str], current_passphrase: Optional[str], hint: Optional[str]) -> bool:
     # Prompt for the current passphrase, if necessary
     if Keychain.has_master_passphrase():
         # Try the default passphrase first
@@ -147,7 +173,10 @@ def set_or_update_passphrase(passphrase: Optional[str], current_passphrase: Opti
             raise ValueError("passphrase is unchanged")
 
         Keychain.set_master_passphrase(
-            current_passphrase=current_passphrase, new_passphrase=new_passphrase, save_passphrase=save_passphrase
+            current_passphrase=current_passphrase,
+            new_passphrase=new_passphrase,
+            passphrase_hint=hint,
+            save_passphrase=save_passphrase,
         )
         success = True
     except Exception as e:
@@ -222,6 +251,44 @@ def using_default_passphrase() -> bool:
     return Keychain.master_passphrase_is_valid(default_passphrase())
 
 
+def display_passphrase_hint() -> None:
+    passphrase_hint = Keychain.get_master_passphrase_hint()
+    if passphrase_hint is not None:
+        print(f"Passphrase hint: {passphrase_hint}")  # lgtm [py/clear-text-logging-sensitive-data]
+    else:
+        print("Passphrase hint is not set")
+
+
+def update_passphrase_hint(hint: Optional[str] = None) -> bool:
+    updated: bool = False
+    if Keychain.has_master_passphrase() is False or using_default_passphrase():
+        print("Updating the passphrase hint requires that a passphrase has been set")
+    else:
+        current_passphrase: Optional[str] = get_current_passphrase()
+        if current_passphrase is None:
+            print("Keyring is not passphrase-protected")
+        else:
+            # Set or remove the passphrase hint
+            Keychain.set_master_passphrase_hint(current_passphrase, hint)
+            updated = True
+
+    return updated
+
+
+def set_passphrase_hint(hint: str) -> None:
+    if update_passphrase_hint(hint):
+        print("Passphrase hint set")
+    else:
+        print("Passphrase hint was not updated")
+
+
+def remove_passphrase_hint() -> None:
+    if update_passphrase_hint(None):
+        print("Passphrase hint removed")
+    else:
+        print("Passphrase hint was not removed")
+
+
 async def async_update_daemon_passphrase_cache_if_running(root_path: Path) -> None:
     """
     Attempt to connect to the daemon and update the cached passphrase
