@@ -38,7 +38,7 @@ async def async_stop(root_path: Path, group: str, stop_daemon: bool) -> int:
 
 @click.command("stop", short_help="Stop services")
 @click.option("-d", "--daemon", is_flag=True, type=bool, help="Stop daemon")
-@click.argument("group", type=click.Choice(all_groups()), nargs=-1, required=True)
+@click.argument("group", type=click.Choice(list(all_groups())), nargs=-1, required=True)
 @click.pass_context
 def stop_cmd(ctx: click.Context, daemon: bool, group: str) -> None:
     import asyncio
