@@ -42,6 +42,12 @@ def calculate_cost_of_program(program: SerializedProgram, npc_result: NPCResult,
                 total_cost += len(cvp_list) * ConditionCost.ASSERT_HEIGHT_RELATIVE.value
             elif condition is ConditionOpcode.ASSERT_MY_COIN_ID:
                 total_cost += len(cvp_list) * ConditionCost.ASSERT_MY_COIN_ID.value
+            elif condition is ConditionOpcode.ASSERT_MY_PARENT_ID:
+                total_cost += len(cvp_list) * ConditionCost.ASSERT_MY_PARENT_ID.value
+            elif condition is ConditionOpcode.ASSERT_MY_PUZZLEHASH:
+                total_cost += len(cvp_list) * ConditionCost.ASSERT_MY_PUZZLEHASH.value
+            elif condition is ConditionOpcode.ASSERT_MY_AMOUNT:
+                total_cost += len(cvp_list) * ConditionCost.ASSERT_MY_AMOUNT.value
             elif condition is ConditionOpcode.RESERVE_FEE:
                 total_cost += len(cvp_list) * ConditionCost.RESERVE_FEE.value
             elif condition is ConditionOpcode.CREATE_COIN_ANNOUNCEMENT:
