@@ -15,6 +15,7 @@ from chia.plotting.util import (
     remove_plot,
     PlotsRefreshParameter,
     PlotRefreshResult,
+    PlotRefreshEvents,
 )
 from chia.util.streamable import dataclass_from_dict
 
@@ -76,15 +77,14 @@ class Harvester:
         if self.state_changed_callback is not None:
             self.state_changed_callback(change)
 
-    def _plot_refresh_callback(self, update_result: PlotRefreshResult):
+    def _plot_refresh_callback(self, event: PlotRefreshEvents, update_result: PlotRefreshResult):
         self.log.info(
-            f"refresh_batch: loaded_plots {update_result.loaded_plots}, "
-            f"loaded_size {update_result.loaded_size / (1024 ** 4):.2f} TiB, "
-            f"removed_plots {update_result.removed_plots}, processed_plots {update_result.processed_files}, "
-            f"remaining_plots {update_result.remaining_files}, "
+            f"refresh_batch: event {event.name}, loaded {update_result.loaded}, "
+            f"removed {update_result.removed}, processed {update_result.processed}, "
+            f"remaining {update_result.remaining}, "
             f"duration: {update_result.duration:.2f} seconds"
         )
-        if update_result.loaded_plots > 0:
+        if update_result.loaded > 0:
             self.event_loop.call_soon_threadsafe(self._state_changed, "plots")
 
     def on_disconnect(self, connection: ws.WSChiaConnection):
