@@ -36,6 +36,12 @@ class uint64(StructStream):
 
 
 class uint128(int):
+    def __new__(cls: Any, value: int):
+        value = int(value)
+        if value > (2 ** 128) - 1 or value < 0:
+            raise ValueError(f"Value {value} of does not fit into uint128")
+        return int.__new__(cls, value)  # type: ignore
+
     @classmethod
     def parse(cls, f: BinaryIO) -> Any:
         read_bytes = f.read(16)
@@ -50,15 +56,24 @@ class uint128(int):
 
 
 class int512(int):
+    def __new__(cls: Any, value: int):
+        value = int(value)
+        # note that the boundaries for int512 is not what you might expect. We
+        # encode these with one extra byte, but only allow a range of
+        # [-INT512_MAX, INT512_MAX]
+        if value >= (2 ** 512) or value <= -(2 ** 512):
+            raise ValueError(f"Value {value} of does not fit into in512")
+        return int.__new__(cls, value)  # type: ignore
+
     # Uses 65 bytes to fit in the sign bit
     @classmethod
     def parse(cls, f: BinaryIO) -> Any:
         read_bytes = f.read(65)
         assert len(read_bytes) == 65
         n = int.from_bytes(read_bytes, "big", signed=True)
-        assert n <= (2 ** 512) - 1 and n >= -(2 ** 512)
+        assert n < (2 ** 512) and n > -(2 ** 512)
         return cls(n)
 
     def stream(self, f):
-        assert self <= (2 ** 512) - 1 and self >= -(2 ** 512)
+        assert self < (2 ** 512) and self > -(2 ** 512)
         f.write(self.to_bytes(65, "big", signed=True))
