@@ -11,9 +11,13 @@ class StructStream(int):
     """
 
     def __new__(cls: Any, value: int):
-        bits = struct.calcsize(cls.PACK) * 8
         value = int(value)
-        if value.bit_length() > bits:
+        try:
+            v1 = struct.unpack(cls.PACK, struct.pack(cls.PACK, value))[0]
+            if value != v1:
+                raise ValueError(f"Value {value} does not fit into {cls.__name__}")
+        except Exception:
+            bits = struct.calcsize(cls.PACK) * 8
             raise ValueError(
                 f"Value {value} of size {value.bit_length()} does not fit into " f"{cls.__name__} of size {bits}"
             )
