@@ -5,7 +5,7 @@ import pytest
 from clvm.casts import int_to_bytes
 
 from chia.consensus.blockchain import ReceiveBlockResult
-from chia.protocols import full_node_protocol
+from chia.protocols import full_node_protocol, wallet_protocol
 from chia.types.announcement import Announcement
 from chia.types.condition_opcodes import ConditionOpcode
 from chia.types.condition_with_args import ConditionWithArgs
@@ -13,7 +13,6 @@ from chia.types.spend_bundle import SpendBundle
 from chia.util.errors import ConsensusError, Err
 from chia.util.ints import uint64
 from tests.wallet_tools import WalletTool
-from tests.core.full_node.test_full_node import connect_and_get_peer
 from tests.setup_nodes import bt, setup_two_nodes, test_constants
 from tests.util.generator_tools_testing import run_and_get_removals_and_additions
 
@@ -48,7 +47,6 @@ class TestBlockchainTransactions:
             num_blocks, farmer_reward_puzzle_hash=coinbase_puzzlehash, guarantee_transaction_block=True
         )
         full_node_api_1, full_node_api_2, server_1, server_2 = two_nodes
-        peer = await connect_and_get_peer(server_1, server_2)
         full_node_1 = full_node_api_1.full_node
 
         for block in blocks:
@@ -63,8 +61,9 @@ class TestBlockchainTransactions:
         spend_bundle = wallet_a.generate_signed_transaction(1000, receiver_puzzlehash, spend_coin)
 
         assert spend_bundle is not None
-        tx: full_node_protocol.RespondTransaction = full_node_protocol.RespondTransaction(spend_bundle)
-        await full_node_api_1.respond_transaction(tx, peer)
+        tx: wallet_protocol.SendTransaction = wallet_protocol.SendTransaction(spend_bundle)
+
+        await full_node_api_1.send_transaction(tx)
 
         sb = full_node_1.mempool_manager.get_spendbundle(spend_bundle.name())
         assert sb is spend_bundle
